@@ -2,7 +2,7 @@ package Bundle::dualLived;
 
 use strict;
 
-$Bundle::dualLived::VERSION = '0.00_06';
+$Bundle::dualLived::VERSION = '1.00';
 
 1;
 
@@ -18,6 +18,8 @@ Bundle::dualLived - Update core dualLived modules
 
 =head1 CONTENTS
 
+arybase
+
 autodie
 
 base
@@ -106,6 +108,8 @@ ExtUtils::Manifest
 
 ExtUtils::ParseXS
 
+ExtUtils::Typemaps
+
 File::Fetch
 
 File::Path
@@ -256,7 +260,7 @@ XSLoader
 
 =head1 AUTHOR
 
-Version 0.00_06 Kevin W. Henwood, <Khen1950fx@aol.com>
+Version 1.00 Kevin W. Henwood, <Khen1950fx@aol.com>
 
 head1 COPYRIGHT AND LICENSE
 
